==> ejc-bid-api-3.0.0-20220323.062913-177-sources.jar: com/ejianc/business/bid/vo/ChoosePersonVO.java <==
package com.ejianc.business.bid.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import com.ejianc.business.bid.vo.ChoosePersonZiVO;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * 中标人员选择
 * 
 * @author generator
 * 
 */
public class ChoosePersonVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编码
    private Long orgId; // 组织id
    private String orgName; // 组织名称
    private Integer billState; // 单据状态（审批必须字段）
    private String createUserName; // 编制人
    private Long operatorId; // 经办人ID
    private String operatorName; // 经办人姓名
    private String updateUserName; // 修改者
    private String remark; // 备注
    private Long xmId; // 项目id
    private String xm; // 项目
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date sqrq; // 申请日期
    private Date billDate; // 编制日期

    private List<ChoosePersonZiVO> choosePersonZiList = new ArrayList<>(); // 中标人员选择子实体

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    @ReferSerialTransfer(referCode = "bid-enroll")
    public Long getXmId() {
        return xmId;
    }

    @ReferDeserialTransfer
    public void setXmId(Long xmId) {
        this.xmId = xmId;
    }
    public String getXm() {
        return xm;
    }

    public void setXm(String xm) {
        this.xm = xm;
    }
    public Date getSqrq() {
        return sqrq;
    }

    public void setSqrq(Date sqrq) {
        this.sqrq = sqrq;
    }
    
     public List<ChoosePersonZiVO> getChoosePersonZiList() {
        return choosePersonZiList;
     }

     public void setChoosePersonZiList(List<ChoosePersonZiVO> choosePersonZiList) {
        this.choosePersonZiList = choosePersonZiList;
     }
    public Date getBillDate() {
        return billDate;
    }

    public void setBillDate(Date billDate) {
        this.billDate = billDate;
    }
}

==> ejc-bid-api-3.0.0-20220328.030134-190-sources.jar: com/ejianc/business/bid/vo/ChoosePersonVO.java <==
package com.ejianc.business.bid.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import com.ejianc.business.bid.vo.ChoosePersonZiVO;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * 中标人员选择
 * 
 * @author generator
 * 
 */
public class ChoosePersonVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编码
    private Long orgId; // 组织id
    private String orgName; // 组织名称
    private Integer billState; // 单据状态（审批必须字段）
    private String createUserName; // 编制人
    private Long operatorId; // 经办人ID
    private String operatorName; // 经办人姓名
    private String updateUserName; // 修改者
    private String remark; // 备注
    private Long xmId; // 项目id
    private String xm; // 项目
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date sqrq; // 申请日期
    private Date billDate; // 编制日期
    private Long xmlxId; // 项目立项id
    private String xmlxName; // 项目立项名称
    private List<ChoosePersonZiVO> choosePersonZiList = new ArrayList<>(); // 中标人员选择子实体

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    @ReferSerialTransfer(referCode = "bid-enroll")    @ReferDeserialTransfer
    public Long getXmId() {
        return xmId;
    }

    @ReferDeserialTransfer
    public void setXmId(Long xmId) {
        this.xmId = xmId;
    }
    public String getXm() {
        return xm;
    }

    public void setXm(String xm) {
        this.xm = xm;
    }
    public Date getSqrq() {
        return sqrq;
    }

    public void setSqrq(Date sqrq) {
        this.sqrq = sqrq;
    }
    
     public List<ChoosePersonZiVO> getChoosePersonZiList() {
        return choosePersonZiList;
     }

     public void setChoosePersonZiList(List<ChoosePersonZiVO> choosePersonZiList) {
        this.choosePersonZiList = choosePersonZiList;
     }
    public Date getBillDate() {
        return billDate;
    }

    public void setBillDate(Date billDate) {
        this.billDate = billDate;
    }
    @ReferSerialTransfer(referCode = "idm-org")
    public Long getXmlxId() {
        return xmlxId;
    }
    @ReferDeserialTransfer
    public void setXmlxId(Long xmlxId) {
        this.xmlxId = xmlxId;
    }

    public String getXmlxName() {
        return xmlxName;
    }

    public void setXmlxName(String xmlxName) {
        this.xmlxName = xmlxName;
    }
}
